/* Hive theme — dark cyan accent
 *
 * accent-low:  subtle backgrounds (low contrast vs page bg)
 * accent:      main brand color (links, active nav)
 * accent-high: text on accent backgrounds (high contrast)
 */

/* Light mode */
:root {
  --sl-color-accent-low: #cffafe;
  --sl-color-accent: #0e7490;
  --sl-color-accent-high: #083344;
}

/* Dark mode */
:root[data-theme='dark'] {
  --sl-color-accent-low: #083344;
  --sl-color-accent: #22d3ee;
  --sl-color-accent-high: #ecfeff;
}
